**Example 1: 强制重新检测域名**



Input: 

```
tccli sslpod RefreshDomain --cli-unfold-argument  \
    --DomainId 13076
```

Output: 
```
{
    "Response": {
        "RequestId": "5627f257-443b-4db4-9081-e7d6ec8b6a71"
    }
}
```

